==> cfg_e5_0_0_10_3_1_3.tar: cfg_e/js/js/tabs/rele_pk4.js <==
function pk4_render_rele() {
    THIS_DEVICE.rele.sort(compareSect);
    let str = '<table class="w3-table w3-table-all">';
    str += '<tr style="background-color: #2196f3">';
    str += '<td>№</td>'
    str += '<td>Тип реле</td>'
    str += '<td>Время работы(сек.)</td>'
    str += '<td>Разделы</td>'
    str += '</tr>';
    let onchangeTime;
    for (var i = 0; i < THIS_DEVICE.rele.length; i++) {
        THIS_DEVICE.rele[i].inline ? onchangeTime = 'pk4_rele_time(this)' : onchangeTime = 'pk4_rele_time_EXT(this)';
        str += '<tr>';
        str += '<td>' + THIS_DEVICE.rele[i].number + '</td>'
        str += '<td>' + pk4_device_type_rele(THIS_DEVICE.rele[i].mode, THIS_DEVICE.rele[i].number, THIS_DEVICE.rele[i].inline) + '</td>'
        str += '<td><input onchange="' + onchangeTime + '" name="' + THIS_DEVICE.rele[i].number + '" style="width:50px" value="' + THIS_DEVICE.rele[i].time + '"></td>'
        str += '<td>' + append_rele_pk4(THIS_DEVICE.rele[i].section, THIS_DEVICE.rele[i].number) + '</td>'
        str += '</tr>';
    }

    str += '</table>';
    document.getElementById('tab_rele_pk4_table').innerHTML = str;
}

function append_rele_pk4(activeSections, number) {
    // Вывод списка раздела реле
    let onchangeSections;
    let str = '';
    str += "<div class='w3-dropdown-hover w3-mobile'>";
    str += "<button class='w3-border w3-border-red w3-btn w3-white'>Разделы</button>";
    str += "<div class='w3-dropdown-content w3-bar-block w3-dark-grey'>";

    for (var i = 1; i <= THIS_DEVICE.sensors.length; i++) {
        str += "<button class='w3-bar-item w3-button'><label'><input onchange='pk4_rele_section(this)' name='" + number + "' id='_r_s" + i + "' type='checkbox' ";
        if (activeSections.includes(i + "")) {
            str += " checked ";
        }
        str += " > Раздел " + i + "</label></button>";
    }
    str += "</div></div>";

    return str
}

function pk4_rele_section(data) {
    // Привязка разделов к реле
    for (var k = 0; k < THIS_DEVICE.rele.length; k++) {
        let znKey = '';
        if (THIS_DEVICE.rele.length <= 1) {
            // В системе 1 РЕЛЕ
            znKey = 'rz';
        } else {
            // В системе БОЛЬШЕ 1 РЕЛЕ
            znKey = 'rz' + data.name;
        }
        dataDevice[znKey] ? '' : znKey = 'oq' + data.name; // Если меняем раздлы для РР то используем oq

        for (i in deviceJSON.config) {
            if (deviceJSON.config[i].key == znKey) {
                //deviceJSON.config[i].subvalues[0].value = data.value; // Псевдоним                
                if (data.checked) {
                    // Доабвление разделов
                    let arrRz = deviceJSON.config[i].subvalues[0].value.split(',');
                    //arrRz.splice(z,1); // удаляем элемент
                    arrRz.push(data.id.slice(4));
                    let newValue = arrRz.join(',');
                    deviceJSON.config[i].subvalues[0].value = newValue;
                    saveConfig(deviceJSON.config[i]);
                    return
                } else {
                    // Удаление разделов                    
                    let arrRz = deviceJSON.config[i].subvalues[0].value.split(',');
                    for (var z = 0; z < arrRz.length; z++) {
                        if (+arrRz[z] === +data.id.slice(4)) {
                            arrRz.splice(z, 1); // удаляем элемент
                            let newValue = arrRz.join(',');
                            deviceJSON.config[i].subvalues[0].value = newValue;
                            saveConfig(deviceJSON.config[i]);
                            return
                        }
                    }
                }
            }
        }
    }
}

function pk4_rele_time(data) {
    // Смена времени работы реле    
    if (data.value > 999) {
        data.value = 999;
    }
    if (data.value < 0) {
        data.value = 0;
    }
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'rm';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'rm' + data.name;
    }
    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[1].value = data.value; // Псевдоним            
            saveConfig(deviceJSON.config[i]);
        }
    }
}

function pk4_rele_time_EXT(data) {
    // Смена времени работы реле    
    if (data.value > 999) {
        data.value = 999;
    }
    if (data.value < 0) {
        data.value = 0;
    }
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'oo';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'oo' + data.name;
    }
    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[1].value = data.value; // Псевдоним            
            saveConfig(deviceJSON.config[i]);
        }
    }
}

function pk4_device_type_rele(value, number, inline) {
    // Отображене типов реле
    // inline - встроенное реле
    let onchangeTyperele;
    inline ? onchangeTyperele = 'pk4_device_set_type_rele(this)' : onchangeTyperele = 'pk4_device_set_type_rele_EXT(this)'
    let str = '';
    str += '<select onchange="' + onchangeTyperele + '" name="' + number + '">';
    if (DEVICEMODEL.charAt(1) === '1') {
        // ППКОП
        str += '<option style="" value="12" ';
        if (value === '12') str += ' selected ';
        str += '>Не используется</option>';
        str += '<option style="background:lightgreen" value="0" ';
        if (value === '0') str += ' selected ';
        str += '>SMS</option>';
        str += '<option style="background:lightgreen" value="1" ';
        if (value === '1') str += ' selected ';
        str += '>ПЦН - Охрана</option>';
        str += '<option style="background:lightgreen" value="2" ';
        if (value === '2') str += ' selected ';
        str += '>Транспарант - Охрана</option>';
        str += '<option style="background:lightgreen" value="3" ';
        if (value === '3') str += ' selected ';
        str += '>Лампа</option>';
        str += '<option style="background:lightgreen" value="4" ';
        if (value === '4') str += ' selected ';
        str += '>Сирена 1</option>';
        str += '<option style="background:lightgreen" value="5" ';
        if (value === '5') str += ' selected ';
        str += '>Сирена 2</option>';
        str += '<option style="background:lightcoral" value="6" ';
        if (value === '6') str += ' selected ';
        str += '>ПЦН - Пожар</option>';
        str += '<option style="background:lightcoral" value="7" ';
        if (value === '7') str += ' selected ';
        str += '>Транспарант - Пожар</option>';
        str += '<option style="background:lightcoral" value="8" ';
        if (value === '8') str += ' selected ';
        str += '>Сирена 1 - Пожар</option>';
        str += '<option style="background:lightcoral" value="9" ';
        if (value === '9') str += ' selected ';
        str += '>Сирена 2 - Пожар</option>';
        str += '<option style="background:lightskyblue" value="10" ';
        if (value === '10') str += ' selected ';
        str += '>Замок</option>';
         str += '<option style="background:lightskyblue" value="11" ';
        if (value === '11') str += ' selected ';
        str += '>Импульс</option>';
        str += '<option style="background:lightcoral" value="14" ';
        if (value === '14') str += ' selected ';
        str += '>АСУПТ</option>';
    } else if (DEVICEMODEL.charAt(1) === '2') {
        // ОО
        str += '<option value="12" ';
        if (value === '12') str += ' selected ';
        str += '>Не используется</option>';
        str += '<option style="background:lightgreen" value="0" ';
        if (value === '0') str += ' selected ';
        str += '>SMS</option>';
        str += '<option style="background:lightgreen" value="1" ';
        if (value === '1') str += ' selected ';
        str += '>ПЦН - Охрана</option>';
        str += '<option style="background:lightgreen" value="2" ';
        if (value === '2') str += ' selected ';
        str += '>Транспарант - Охрана</option>';
        str += '<option style="background:lightgreen" value="3" ';
        if (value === '3') str += ' selected ';
        str += '>Лампа</option>';
        str += '<option style="background:lightgreen" value="4" ';
        if (value === '4') str += ' selected ';
        str += '>Сирена 1</option>';
        str += '<option style="background:lightgreen" value="5" ';
        if (value === '5') str += ' selected ';
        str += '>Сирена 2</option>';
        str += '<option style="background:lightskyblue" value="10" ';
        if (value === '10') str += ' selected ';
        str += '>Замок</option>';
    }

    str += '</select>';

    return str
}

function pk4_device_set_type_rele(data) {
    // Смена типа реле
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'rm';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'rm' + data.name;
    }

    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[0].value = data.value;
            saveConfig(deviceJSON.config[i]);
        }
    }
    pk4_init_key();
}

function pk4_device_set_type_rele_EXT(data) {
    // Смена типа реле
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'oo';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'oo' + data.name;
    }

    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[0].value = data.value;
            saveConfig(deviceJSON.config[i]);
        }
    }
    pk4_init_key();
}

==> cfg_e5_0_1_16_5_2_10.tar: cfg_e/js/js/tabs/rele_pk4.js <==
function pk4_render_rele() {
    THIS_DEVICE.rele.sort(compareSect);
    let str = '<table class="w3-table w3-table-all">';
    str += '<tr style="background-color: #2196f3">';
    str += '<td>№</td>'
    str += '<td>Тип реле</td>'
    str += '<td>Время работы(сек.)</td>'
    str += '<td>Разделы</td>'
    str += '</tr>';
    let onchangeTime;
    for (var i = 0; i < THIS_DEVICE.rele.length; i++) {
        THIS_DEVICE.rele[i].inline ? onchangeTime = 'pk4_rele_time(this)' : onchangeTime = 'pk4_rele_time_EXT(this)';
        str += '<tr>';
        str += '<td>' + THIS_DEVICE.rele[i].number + '</td>'
        str += '<td>' + pk4_device_type_rele(THIS_DEVICE.rele[i].mode, THIS_DEVICE.rele[i].number, THIS_DEVICE.rele[i].inline) + '</td>'
        str += '<td><input onchange="' + onchangeTime + '" name="' + THIS_DEVICE.rele[i].number + '" style="width:50px" value="' + THIS_DEVICE.rele[i].time + '"></td>'
        str += '<td>' + append_rele_pk4(THIS_DEVICE.rele[i].section, THIS_DEVICE.rele[i].number) + '</td>'
        str += '</tr>';
    }

    str += '</table>';
    document.getElementById('tab_rele_pk4_table').innerHTML = str;
}

function append_rele_pk4(activeSections, number) {
    // Вывод списка раздела реле
    let onchangeSections;
    let str = '';
    str += "<div class='w3-dropdown-hover w3-mobile'>";
    str += "<button class='w3-border w3-border-red w3-btn w3-white'>Разделы</button>";
    str += "<div class='w3-dropdown-content w3-bar-block w3-dark-grey'>";

    for (var i = 1; i <= THIS_DEVICE.sensors.length; i++) {
        str += "<label class='w3-bar-item w3-button'><input onchange='pk4_rele_section(this)' name='" + number + "' id='_r_s" + i + "' type='checkbox' ";
        if (activeSections.includes(i + "")) {
            str += " checked ";
        }
        str += " > Раздел " + i + "</label>";
    }
    str += "</div></div>";

    return str
}

function pk4_rele_section(data) {
    // Привязка разделов к реле
    for (var k = 0; k < THIS_DEVICE.rele.length; k++) {
        let znKey = '';
        if (THIS_DEVICE.rele.length <= 1) {
            // В системе 1 РЕЛЕ
            znKey = 'rz';
        } else {
            // В системе БОЛЬШЕ 1 РЕЛЕ
            znKey = 'rz' + data.name;
        }
        dataDevice[znKey] ? '' : znKey = 'oq' + data.name; // Если меняем раздлы для РР то используем oq

        for (i in deviceJSON.config) {
            if (deviceJSON.config[i].key == znKey) {
                //deviceJSON.config[i].subvalues[0].value = data.value; // Псевдоним                
                if (data.checked) {
                    // Доабвление разделов
                    let arrRz = deviceJSON.config[i].subvalues[0].value.split(',');
                    //arrRz.splice(z,1); // удаляем элемент
                    arrRz.push(data.id.slice(4));
                    let newValue = arrRz.join(',');
                    deviceJSON.config[i].subvalues[0].value = newValue;
                    saveConfig(deviceJSON.config[i]);
                    return
                } else {
                    // Удаление разделов                    
                    let arrRz = deviceJSON.config[i].subvalues[0].value.split(',');
                    for (var z = 0; z < arrRz.length; z++) {
                        if (+arrRz[z] === +data.id.slice(4)) {
                            arrRz.splice(z, 1); // удаляем элемент
                            let newValue = arrRz.join(',');
                            deviceJSON.config[i].subvalues[0].value = newValue;
                            saveConfig(deviceJSON.config[i]);
                            return
                        }
                    }
                }
            }
        }
    }
}

function pk4_rele_time(data) {
    // Смена времени работы реле    
    if (data.value > 999) {
        data.value = 999;
    }
    if (data.value < 0) {
        data.value = 0;
    }
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'rm';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'rm' + data.name;
    }
    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[1].value = data.value; // Псевдоним            
            saveConfig(deviceJSON.config[i]);
        }
    }
}

function pk4_rele_time_EXT(data) {
    // Смена времени работы реле    
    if (data.value > 999) {
        data.value = 999;
    }
    if (data.value < 0) {
        data.value = 0;
    }
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'oo';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'oo' + data.name;
    }
    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[1].value = data.value; // Псевдоним            
            saveConfig(deviceJSON.config[i]);
        }
    }
}

function pk4_device_type_rele(value, number, inline) {
    // Отображене типов реле
    // inline - встроенное реле
    let onchangeTyperele;
    inline ? onchangeTyperele = 'pk4_device_set_type_rele(this)' : onchangeTyperele = 'pk4_device_set_type_rele_EXT(this)'
    let str = '';
    str += '<select onchange="' + onchangeTyperele + '" name="' + number + '">';
    if (DEVICEMODEL.charAt(1) === '1') {
        // ППКОП
        str += '<option style="" value="12" ';
        if (value === '12') str += ' selected ';
        str += '>Не используется</option>';
        str += '<option style="background:lightgreen" value="0" ';
        if (value === '0') str += ' selected ';
        str += '>SMS</option>';
        str += '<option style="background:lightgreen" value="1" ';
        if (value === '1') str += ' selected ';
        str += '>ПЦН - Охрана</option>';
        str += '<option style="background:lightgreen" value="2" ';
        if (value === '2') str += ' selected ';
        str += '>Транспарант - Охрана</option>';
        str += '<option style="background:lightgreen" value="3" ';
        if (value === '3') str += ' selected ';
        str += '>Лампа</option>';
        str += '<option style="background:lightgreen" value="4" ';
        if (value === '4') str += ' selected ';
        str += '>Сирена 1</option>';
        str += '<option style="background:lightgreen" value="5" ';
        if (value === '5') str += ' selected ';
        str += '>Сирена 2</option>';
        str += '<option style="background:lightcoral" value="6" ';
        if (value === '6') str += ' selected ';
        str += '>ПЦН - Пожар</option>';
        str += '<option style="background:lightcoral" value="7" ';
        if (value === '7') str += ' selected ';
        str += '>Транспарант - Пожар</option>';
        str += '<option style="background:lightcoral" value="8" ';
        if (value === '8') str += ' selected ';
        str += '>Сирена 1 - Пожар</option>';
        str += '<option style="background:lightcoral" value="9" ';
        if (value === '9') str += ' selected ';
        str += '>Сирена 2 - Пожар</option>';
        str += '<option style="background:lightskyblue" value="10" ';
        if (value === '10') str += ' selected ';
        str += '>Замок</option>';
         str += '<option style="background:lightskyblue" value="11" ';
        if (value === '11') str += ' selected ';
        str += '>Импульс</option>';
        str += '<option style="background:lightcoral" value="14" ';
        if (value === '14') str += ' selected ';
        str += '>АСУПТ</option>';
    } else if (DEVICEMODEL.charAt(1) === '2') {
        // ОО
        str += '<option value="12" ';
        if (value === '12') str += ' selected ';
        str += '>Не используется</option>';
        str += '<option style="background:lightgreen" value="0" ';
        if (value === '0') str += ' selected ';
        str += '>SMS</option>';
        str += '<option style="background:lightgreen" value="1" ';
        if (value === '1') str += ' selected ';
        str += '>ПЦН - Охрана</option>';
        str += '<option style="background:lightgreen" value="2" ';
        if (value === '2') str += ' selected ';
        str += '>Транспарант - Охрана</option>';
        str += '<option style="background:lightgreen" value="3" ';
        if (value === '3') str += ' selected ';
        str += '>Лампа</option>';
        str += '<option style="background:lightgreen" value="4" ';
        if (value === '4') str += ' selected ';
        str += '>Сирена 1</option>';
        str += '<option style="background:lightgreen" value="5" ';
        if (value === '5') str += ' selected ';
        str += '>Сирена 2</option>';
        str += '<option style="background:lightskyblue" value="10" ';
        if (value === '10') str += ' selected ';
        str += '>Замок</option>';
    }

    str += '</select>';

    return str
}

function pk4_device_set_type_rele(data) {
    // Смена типа реле
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'rm';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'rm' + data.name;
    }

    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[0].value = data.value;
            saveConfig(deviceJSON.config[i]);
        }
    }
    pk4_init_key();
}

function pk4_device_set_type_rele_EXT(data) {
    // Смена типа реле
    let rmKey = '';
    if (THIS_DEVICE.rele.length <= 1) {
        // В системе 1 РЕЛЕ
        rmKey = 'oo';
    } else {
        // В системе БОЛЬШЕ 1 РЕЛЕ
        rmKey = 'oo' + data.name;
    }

    for (i in deviceJSON.config) {
        if (deviceJSON.config[i].key == rmKey) {
            deviceJSON.config[i].subvalues[0].value = data.value;
            saveConfig(deviceJSON.config[i]);
        }
    }
    pk4_init_key();
}
